Package: oncoscanR
Type: Package
Title: Secondary analyses of CNV data (HRD and more)
Version: 1.12.0
Authors@R: c(person("Yann", "Christinat", email = "yann.christinat@hcuge.ch", 
                  role = c("aut", "cre")),
             person("Geneva University Hospitals", role=c("aut", "cph")))
Description: The software uses the copy number segments from a text file and 
    identifies all chromosome arms that are globally altered and computes various 
    genome-wide scores. The following HRD scores (characteristic of BRCA-mutated cancers) 
    are included: LST, HR-LOH, nLST and gLOH. the package is tailored for the 
    ThermoFisher Oncoscan assay analyzed with their Chromosome Alteration Suite 
    (ChAS) but can be adapted to any input.
License: MIT + file LICENSE
Date: 2025-06-27
Encoding: UTF-8
VignetteBuilder: knitr
biocViews: CopyNumberVariation, Microarray, Software
Imports: readr, S4Vectors, methods, utils
RoxygenNote: 7.3.2
Depends: R (>= 4.2), IRanges (>= 2.30.0), GenomicRanges (>= 1.48.0),
        magrittr
Suggests: testthat (>= 3.1.4), jsonlite, knitr, rmarkdown, BiocStyle
URL: https://github.com/yannchristinat/oncoscanR
BugReports: https://github.com/yannchristinat/oncoscanR/issues
LazyData: true
git_url: https://git.bioconductor.org/packages/oncoscanR
git_branch: RELEASE_3_22
git_last_commit: 11be7a3
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 05:32:25 UTC; biocbuild
Author: Yann Christinat [aut, cre],
  Geneva University Hospitals [aut, cph]
Maintainer: Yann Christinat <yann.christinat@hcuge.ch>
