# Generated by roxygen2: do not edit by hand

export(adjust_loh)
export(armlevel_alt)
export(get_amp_segments)
export(get_gain_segments)
export(get_hetloss_segments)
export(get_homloss_segments)
export(get_loh_segments)
export(get_loss_segments)
export(get_oncoscan_coverage_from_bed)
export(load_ascat)
export(load_chas)
export(merge_segments)
export(prune_by_size)
export(score_avgcn)
export(score_estwgd)
export(score_gloh)
export(score_loh)
export(score_lst)
export(score_mbalt)
export(score_nlst)
export(score_td)
export(trim_to_coverage)
export(workflow_oncoscan.ascat)
export(workflow_oncoscan.chas)
import(GenomicRanges)
import(IRanges)
import(S4Vectors)
import(readr)
importFrom(magrittr,"%>%")
importFrom(methods,is)
importFrom(utils,read.table)
